# Flytekit dbt plugin

Flytekit plugin for performing DBT tasks. Currently it supports both `dbt run` and `dbt test` tasks.

To install the plugin, run the following command:

```bash
pip install flytekitplugins-dbt
```

_Example coming soon!_

## Contributors

- [Gojek](https://www.gojek.io/)
